@@ -18,6 +18,10 @@ class OAuth2ProviderConfig(BaseModel):
     provider: str
     client_id: str
     client_secret: str
+    additional_scopes: list[str] = Field(
+        default_factory=list,
+        description="Additional scopes",
+    )
 
 
 class OAuth2Config(BaseModel):
@@ -32,10 +36,12 @@ class OAuth2Config(BaseModel):
 
     enable_redirect_endpoint: bool = True
 
-    def add_provider(self, name: str, client_id: str, client_secret: str):
+    def add_provider(self, name: str, client_id: str, client_secret: str, additional_scopes: list[str] = None):
+        if additional_scopes is None:
+            additional_scopes = []
         self.providers.append(
             OAuth2ProviderConfig(
-                provider=name, client_id=client_id, client_secret=client_secret
+                provider=name, client_id=client_id, client_secret=client_secret, additional_scopes=additional_scopes,
             )
         )
 
