@@ -29,12 +29,14 @@ async def oauth2_options(request: Request):
         provider_config = get_provider_config(name)
         if not provider_config:
             continue
+        scopes = set(provider.scopes)
+        scopes.update(provider_config.additional_scopes)
         result.append(
             OAuth2Option(
                 name=name,
                 url=provider.authorization_endpoint,
                 client_id=provider_config.client_id,
-                scope=provider.scope,
+                scope=" ".join(list(scopes)),
             )
         )
     return OAuth2Options(options=result)
