@@ -25,7 +25,7 @@ class OAuth2Provider(BaseModel):
     revocation_endpoint: str = Field(..., description="Revoke URL")
     userinfo_endpoint: str = Field(..., description="User info endpoint")
     userinfo_parser: Callable = Field(..., description="User info parser")
-    scope: str = Field(..., description="Scope")
+    scopes: list[str] = Field(..., description="Scope")
 
 
 class OAuth2Option(BaseModel):
@@ -76,7 +76,5 @@ class OAuth2Data(BaseModel):
     user: OAuth2UserInfo = Field(..., description="User information.")
     provider: str = Field(..., description="Name of the OAuth2 provider")
     access_token: str = Field(..., description="OAuth2 access token")
-
     refresh_token: str | None = Field(None, description="OAuth2 refresh token")
-
     expires_at: int | None = Field(None, description="OAuth2 token expiration time")
