@@ -2,6 +2,9 @@
 
 __all__ = ["discord"]
 
+import json
+
+
 from ..models import OAuth2Provider, OAuth2UserInfo
 
 
@@ -29,5 +32,5 @@ discord = OAuth2Provider(
     userinfo_endpoint="https://discordapp.com/api/users/%40me",
     revocation_endpoint="https://discordapp.com/api/oauth2/token/revoke",
     userinfo_parser=parse_user,
-    scope="identify email",
+    scopes=["identify", "email"],
 )
